@@ -13,6 +13,7 @@
 #include "explain.h"
 #include "filters.h"
 #include "mlocate.h"
+#include "plocate.h"
 #include "dpkg.h"
 #include "dpkg_exclude.h"
 
@@ -22,7 +23,7 @@ using namespace std;
 
 int read_mounts(vector<string>& prunefs, vector<string>& mounts)
 {
-	// this doesn't include "/", as it allways exists
+	// this doesn't include "/", as it always exists
 	ifstream mtab("/proc/mounts");
 	string mount,type;
 	while ( not mtab.eof() )
@@ -53,14 +54,25 @@ int read_mounts(vector<string>& prunefs, vector<string>& mounts)
 	return 0;
 }
 
-void updatedb()
+void updatedb(string db)
 {
 	if (getuid()) return;
-	//TODO: compare mtime /var/cache/apt/pkgcache.bin
-	//      et mtime      /var/lib/mlocate/mlocate.db
-	//      et date systeme
+
+	int rc_locate, rc_dpkg;
+	struct stat stat_locate, stat_dpkg;
+	rc_locate = stat(db.c_str(), &stat_locate);
+	rc_dpkg = stat("/var/lib/dpkg/status", &stat_dpkg);
+
+	if (rc_dpkg) {
+		cerr << "can't read /var/lib/dpkg/status timestamp !!!" << endl;
+		exit(1);
+	}
+
+	if (!rc_locate && stat_locate.st_mtim.tv_sec > stat_dpkg.st_mtim.tv_sec)
+		return;
+
 	if (system("updatedb")) {
-		cerr << "mlocates's updatedb failed" << endl;
+		cerr << "updatedb failed" << endl;
 		exit(1);
 	}
 }
@@ -208,10 +220,18 @@ int main(int argc, char *argv[])
 		cerr << "if not, the whole system is analysed" << endl;
 		exit(1);
 	}
-	updatedb();
 
 	std::vector<string> fs,prunefs,mounts;
-	read_mlocate(fs,prunefs);
+
+	struct stat has_plocate;
+	if (stat("/var/lib/plocate/plocate.db", &has_plocate) == 0) {
+		updatedb("/var/lib/plocate/plocate.db");
+		read_plocate(fs,prunefs);
+	} else {
+		updatedb("/var/lib/mlocate/mlocate.db");
+		read_mlocate(fs,prunefs);
+	}
+
 	read_mounts(prunefs,mounts);
 
 	const int SIZEBUF = 200;
