@@ -2,7 +2,11 @@
 #include <fstream>
 #include <algorithm>
 #include <limits>
-#include <mlocate/db.h>
+#include "mlocate_db.h"
+//       original filename is 'db.h'
+// TODO: should be packaged in /usr/include by 'mlocate' package
+//       like 'make' provides '/usr/include/gnumake.h'
+//       and  'sudo' provides '/usr/include/sudo_plugin.h'
 
 #include "mlocate.h"
 
